# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['Checkpointing',
 'Checkpointing.ChkptDescFileGen',
 'Checkpointing.DumpHTIF',
 'Checkpointing.SyscallAnalysis',
 'Checkpointing.SyscallAnalysis.libsyscall',
 'Checkpointing.SyscallAnalysis.libsyscall.analyzer',
 'Checkpointing.SyscallAnalysis.libsyscall.syscalls',
 'Checkpointing.SyscallAnalysis.test',
 'CpuTraceAnalysis',
 'CpuTraceAnalysis.libcputrace',
 'CpuTraceAnalysis.libcputrace.MachineCode',
 'CpuTraceAnalysis.libcputrace.StackAnalysis',
 'CpuTraceAnalysis.libcputrace.StackAnalysis.Recorder',
 'CpuTraceAnalysis.libcputrace.Trace',
 'SpecResultVerification',
 'TetherSim']

package_data = \
{'': ['*'],
 'CpuTraceAnalysis': ['trace_vis/*',
                      'trace_vis/node_modules/vis-timeline/*',
                      'trace_vis/node_modules/vis-timeline/declarations/*',
                      'trace_vis/node_modules/vis-timeline/dist/*',
                      'trace_vis/node_modules/vis-timeline/dist/types/*',
                      'trace_vis/node_modules/vis-timeline/esnext/*',
                      'trace_vis/node_modules/vis-timeline/esnext/esm/*',
                      'trace_vis/node_modules/vis-timeline/esnext/umd/*',
                      'trace_vis/node_modules/vis-timeline/peer/*',
                      'trace_vis/node_modules/vis-timeline/peer/esm/*',
                      'trace_vis/node_modules/vis-timeline/peer/umd/*',
                      'trace_vis/node_modules/vis-timeline/standalone/*',
                      'trace_vis/node_modules/vis-timeline/standalone/esm/*',
                      'trace_vis/node_modules/vis-timeline/standalone/umd/*',
                      'trace_vis/node_modules/vis-timeline/styles/*',
                      'trace_vis/node_modules/vis-timeline/types/*']}

install_requires = \
['PyYAML>=5.3.1,<6.0.0',
 'click>=7.1.2,<8.0.0',
 'fuzzywuzzy>=0.18.0,<0.19.0',
 'pyparsing>=2.4.7,<3.0.0',
 'python-Levenshtein>=0.12.0,<0.13.0']

entry_points = \
{'console_scripts': ['atool_SimTetheringController = '
                     'TetherSim.SimTetheringController:main',
                     'atool_chkpt_htif_dump = '
                     'Checkpointing.DumpHTIF.chkpt_htif_dump:main',
                     'atool_generate_manifest = '
                     'Checkpointing.SyscallAnalysis.generate_manifest:main',
                     'atool_prerun_check = '
                     'Checkpointing.SyscallAnalysis.prerun_check:main',
                     'atool_smpt2ckptdesc = '
                     'Checkpointing.ChkptDescFileGen.smpt2ckptdesc:main',
                     'atool_spike_trim = '
                     'SpecResultVerification.spike_trim:main',
                     'atool_trace2google = CpuTraceAnalysis.trace2google:main',
                     'atool_trace2tracevis = '
                     'CpuTraceAnalysis.trace2tracevis:main',
                     'atool_trace_diff = CpuTraceAnalysis.trace_diff:main']}

setup_kwargs = {
    'name': 'anycore-dbg-supplement',
    'version': '0.0.2',
    'description': 'A bundle of auxiliary scripts for the Anycore project',
    'long_description': "## Pre-Simulation readiness checking\n\n- `Checkpointing/SyscallAnalysis/prerun_check.py` - Perform a prerun check based on the info in manifest DB.\n- `Checkpointing/SyscallAnalysis/generate_manifest.py` - Analyze the System Call trace for an entire SPEC simulation (dumped by a special version of [spike](https://github.com/s117/riscv-isa-sim/tree/feature_syscall_trace)). Then produce the manifest for it. Finally save the manifest into DB.\n\n\n## Misc.\n\n- `SpecResultVerification/spike_trim.py` - Trim out the extra header/tail message produced by spike or pk during the simulation. Useful if you want to automatically verify the STDOUT output of a SPEC simulation.\n- `Checkpointing/ChkptDescFileGen/smpt2ckptdesc.py` - Convert the Simpoint output file to the checkpoint job description file accepted by Spike.\n- `Checkpointing/DumpHTIF/chkpt_htif_dump.py` - Show the HTIF syscalls recorded in a checkpoint file. When restoring a checkpoint, those syscalls will be executed in sequence to bring back the state of [HTIF FESVR](https://github.com/s117/riscv-fesvr).\n- `TetherSim/SimTetheringController.py` - Controller for [721sims](https://github.ncsu.edu/jli95/721sim/tree/trace_support) working in tethering mode.\n\n\n## To work with trace dump\n\n- `CpuTraceAnalysis/trace2google.py` - Analyze the trace dumped by [spike](https://github.com/s117/riscv-isa-sim/tree/WIB_trace_support) or [721sim](https://github.ncsu.edu/jli95/721sim/tree/trace_support) and output the result in Google's Trace Event Format.\n- To visualize the result, use [speedscope](https://github.com/jlfwong/speedscope) (recommend) or Chromium's *about://tracing* .\n  - if `ignore_symbol.yaml` exists in CWD, it will be read to filter out the defined function calls. See `CpuTraceAnalysis/ignore_symbol.yaml` for an example.\n\n- `CpuTraceAnalysis/trace2tracevis.py` - Analyze and visualize the trace dumped by [spike](https://github.com/s117/riscv-isa-sim/tree/WIB_trace_support) or [721sim](https://github.ncsu.edu/jli95/721sim/tree/trace_support) in a homebrew timeline frontend (using [timeline-js](https://github.com/visjs/vis-timeline)).\n  - if `ignore_symbol.yaml` exists in CWD - Will be read to filter out the defined function calls. See `CpuTraceAnalysis/ignore_symbol.yaml` for an example.\n  - **It's recommended to use `trace2google.py`.** Because the trace_vis frontend uses timeline-js, which is not intended for visualizing tracing result, it can be very slow and unresponsive when working with trace with a large amount of event.\n\n![image-20201105011703029](https://raw.githubusercontent.com/s117/anycore-dbg-supplement/master/README.assets/image-20201105011703029.png)\n\n<p align=center>Viewing the trace2google.py output with speedscope</p>\n\n![image-20201105011839379](https://raw.githubusercontent.com/s117/anycore-dbg-supplement/master/README.assets/image-20201105011839379.png)\n\n<p align=center>Viewing the trace2google.py output with Chrome's about:tracing</p>\n\n![image-20200813043919822](https://raw.githubusercontent.com/s117/anycore-dbg-supplement/master/README.assets/image-20200813043919822.png)\n\n<p align=center>Viewing the trace using homebrew TraceVis frontend (use timeline-js)</p>\n\n**WIP**.",
    'author': 'Jiayang Li',
    'author_email': 'jli95@ncsu.edu',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/s117/anycore-dbg-supplement.git',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
